@@ -23,7 +23,7 @@ from rio_tiler.errors import (
 from rio_tiler.models import BandStatistics, ImageData, Info, PointData
 from rio_tiler.tasks import multi_arrays, multi_points, multi_values
 from rio_tiler.types import AssetInfo, BBox, Indexes
-from rio_tiler.utils import get_array_statistics, normalize_bounds
+from rio_tiler.utils import normalize_bounds
 
 
 @attr.s
@@ -364,7 +364,7 @@ class MultiBaseReader(SpatialMixin, metaclass=abc.ABCMeta):
         asset_indexes: Optional[Dict[str, Indexes]] = None,  # Indexes for each asset
         categorical: bool = False,
         categories: Optional[List[float]] = None,
-        percentiles: List[int] = [2, 98],
+        percentiles: Optional[List[int]] = None,
         hist_options: Optional[Dict] = None,
         max_size: int = 1024,
         **kwargs: Any,
@@ -402,22 +402,13 @@ class MultiBaseReader(SpatialMixin, metaclass=abc.ABCMeta):
             max_size=max_size,
             **kwargs,
         )
-
-        hist_options = hist_options or {}
-
-        stats = get_array_statistics(
-            data.as_masked(),
+        return data.statistics(
             categorical=categorical,
             categories=categories,
             percentiles=percentiles,
-            **hist_options,
+            hist_options=hist_options,
         )
 
-        return {
-            f"{data.band_names[ix]}": BandStatistics(**stats[ix])
-            for ix in range(len(stats))
-        }
-
     def tile(
         self,
         tile_x: int,
@@ -861,7 +852,7 @@ class MultiBandReader(SpatialMixin, metaclass=abc.ABCMeta):
         expression: Optional[str] = None,
         categorical: bool = False,
         categories: Optional[List[float]] = None,
-        percentiles: List[int] = [2, 98],
+        percentiles: Optional[List[int]] = None,
         hist_options: Optional[Dict] = None,
         max_size: int = 1024,
         **kwargs: Any,
@@ -896,22 +887,13 @@ class MultiBandReader(SpatialMixin, metaclass=abc.ABCMeta):
             max_size=max_size,
             **kwargs,
         )
-
-        hist_options = hist_options or {}
-
-        stats = get_array_statistics(
-            data.as_masked(),
+        return data.statistics(
             categorical=categorical,
             categories=categories,
             percentiles=percentiles,
-            **hist_options,
+            hist_options=hist_options,
         )
 
-        return {
-            f"{data.band_names[ix]}": BandStatistics(**stats[ix])
-            for ix in range(len(stats))
-        }
-
     def tile(
         self,
         tile_x: int,
