@@ -64,7 +64,7 @@ def get_array_statistics(
     data: numpy.ma.MaskedArray,
     categorical: bool = False,
     categories: Optional[List[float]] = None,
-    percentiles: List[int] = [2, 98],
+    percentiles: Optional[List[int]] = None,
     **kwargs: Any,
 ) -> List[Dict[Any, Any]]:
     """Calculate per band array statistics.
@@ -107,6 +107,8 @@ def get_array_statistics(
         ]
 
     """
+    percentiles = percentiles or [2, 98]
+
     if len(data.shape) < 3:
         data = numpy.expand_dims(data, axis=0)
 
@@ -207,13 +209,17 @@ def get_overview_level(
     if target_res > src_res:
         res = [src_res * decim for decim in src_dst.overviews(1)]
 
-        for ovr_idx in range(ovr_idx, len(res) - 1):
+        for idx in range(ovr_idx, len(res) - 1):
+            ovr_idx = idx
             ovrRes = src_res if ovr_idx < 0 else res[ovr_idx]
             nextRes = res[ovr_idx + 1]
+
             if (ovrRes < target_res) and (nextRes > target_res):
                 break
+
             if abs(ovrRes - target_res) < 1e-1:
                 break
+
         else:
             ovr_idx = len(res) - 1
 
@@ -417,16 +423,18 @@ def render(
 
     if colormap:
         data, alpha = apply_cmap(data, colormap)
+        # We take both the input mask and the alpha from the colormap
+        # if input mask is not provided then we assume output is wanted without alpha band
+        # this can be seen as a bug but at the time of writing we assume it's a feature.
         if mask is not None:
-            mask = (
-                mask * alpha * 255
-            )  # This is a special case when we want to mask some valid data
+            mask = numpy.bitwise_and(alpha, mask)
 
     # WEBP doesn't support 1band dataset so we must hack to create a RGB dataset
     if img_format == "WEBP" and data.shape[0] == 1:
         data = numpy.repeat(data, 3, axis=0)
 
     if img_format == "PNG" and data.dtype == "uint16" and mask is not None:
+        # By rio-tiler design, mask should always be between 0 and 255
         mask = linear_rescale(mask, (0, 255), (0, 65535)).astype("uint16")
 
     elif img_format == "JPEG":
@@ -448,17 +456,18 @@ def render(
                 numpy.savez_compressed(bio, data=data, mask=mask)
             else:
                 numpy.savez_compressed(bio, data=data)
+
             return bio.getvalue()
 
     count, height, width = data.shape
 
-    output_profile = dict(
-        driver=img_format,
-        dtype=data.dtype,
-        count=count + 1 if mask is not None else count,
-        height=height,
-        width=width,
-    )
+    output_profile = {
+        "driver": img_format,
+        "dtype": data.dtype,
+        "count": count + 1 if mask is not None else count,
+        "height": height,
+        "width": width,
+    }
     output_profile.update(creation_options)
 
     with warnings.catch_warnings():
@@ -466,10 +475,12 @@ def render(
         with MemoryFile() as memfile:
             with memfile.open(**output_profile) as dst:
                 dst.write(data, indexes=list(range(1, count + 1)))
+
                 # Use Mask as an alpha band
                 if mask is not None:
                     if ColorInterp.alpha not in dst.colorinterp:
                         dst.colorinterp = *dst.colorinterp[:-1], ColorInterp.alpha
+
                     dst.write(mask.astype(data.dtype), indexes=count + 1)
 
             return memfile.read()
